require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_updateservicesapprovalrule',
  dscmeta_resource_friendly_name: 'UpdateServicesApprovalRule',
  dscmeta_resource_name: 'MSFT_UpdateServicesApprovalRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'UpdateServicesDsc',
  dscmeta_module_version: '1.2.1',
  docs: 'The DSC UpdateServicesApprovalRule resource type.
         Automatically generated from version 1.2.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_computergroups: {
      type: 'Optional[Array[String]]',
      desc: 'Computer groups the approval rule applies to.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Whether the approval rule is enabled.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_classifications: {
      type: 'Optional[Array[String]]',
      desc: 'Classifications in the approval rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'An enumerated value that describes if WSUS is configured. Present {default}   Absent    ',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runrulenow: {
      type: 'Optional[Boolean]',
      desc: 'Run the approval rule after it has been created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the approval rule.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_synchronize: {
      type: 'Optional[Boolean]',
      desc: 'Synchronize after creating or updating the approval rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_products: {
      type: 'Optional[Array[String]]',
      desc: 'Products in the approval rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
