require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_updateservicescleanup',
  dscmeta_resource_friendly_name: 'UpdateServicesCleanup',
  dscmeta_resource_name: 'MSFT_UpdateServicesCleanup',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'UpdateServicesDsc',
  dscmeta_module_version: '1.2.1',
  docs: 'The DSC UpdateServicesCleanup resource type.
         Automatically generated from version 1.2.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_declineexpiredupdates: {
      type: 'Optional[Boolean]',
      desc: "Decline updates that aren't approved and have been expired by Microsoft.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_timeofday: {
      type: 'Optional[String]',
      desc: 'Time of day to start cleanup.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_compressupdates: {
      type: 'Optional[Boolean]',
      desc: 'Compress updates.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cleanuplocalpublishedcontentfiles: {
      type: 'Optional[Boolean]',
      desc: 'Cleanup local published content files.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cleanupunneededcontentfiles: {
      type: 'Optional[Boolean]',
      desc: "Delete update files that aren't needed by updates or downstream servers.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_declinesupersededupdates: {
      type: 'Optional[Boolean]',
      desc: 'Decline updates that have not been approved fo 30 days or more, are not currently needed by any clients, and are superseded by an approved update.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'present', 'Absent', 'absent']",
      desc: 'An enumerated value that describes if the WSUS cleanup task exists. Present {default}   Absent    ',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cleanupobsoletecomputers: {
      type: 'Optional[Boolean]',
      desc: 'Delete computers that have not contacted the server in 30 days or more.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cleanupobsoleteupdates: {
      type: 'Optional[Boolean]',
      desc: 'Delete updates that are expired and have not been approved for 30 days or more, and delete older update revisions that have not been approved for 30 days or more.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
