require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_updateservicesserver',
  dscmeta_resource_friendly_name: 'UpdateServicesServer',
  dscmeta_resource_name: 'MSFT_UpdateServicesServer',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'UpdateServicesDsc',
  dscmeta_module_version: '1.2.1',
  docs: 'The DSC UpdateServicesServer resource type.
         Automatically generated from version 1.2.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_updateimprovementprogram: {
      type: 'Optional[Boolean]',
      desc: 'Join the Microsoft Update Improvement Program.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sqlserver: {
      type: 'Optional[String]',
      desc: 'SQL Server for the WSUS database, omit for Windows Internal Database.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_synchronizationsperday: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Synchronizations per day.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_proxyservercredentialusername: {
      type: 'Optional[String]',
      desc: 'Proxy server credential username.',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_upstreamservername: {
      type: 'Optional[String]',
      desc: 'Upstream WSUS server, omit for Microsoft Update.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_products: {
      type: 'Optional[Array[String]]',
      desc: 'Update products, * for all.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_upstreamserverreplica: {
      type: 'Optional[Boolean]',
      desc: 'Replica of upstream WSUS server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_classifications: {
      type: 'Optional[Array[String]]',
      desc: 'Update classifications, * for all.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_synchronizeautomaticallytimeofday: {
      type: 'Optional[String]',
      desc: 'First synchronization.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'present', 'Absent', 'absent']",
      desc: 'An enumerated value that describes if WSUS is configured. Present {default}   Absent    ',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyservercredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Proxy server credential, omit for anonymous.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_synchronize: {
      type: 'Optional[Boolean]',
      desc: 'Begin initial synchronization.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_languages: {
      type: 'Optional[Array[String]]',
      desc: 'Update languages, * for all.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_proxyservername: {
      type: 'Optional[String]',
      desc: 'Proxy server to use when synchronizing, omit for no proxy.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyserverport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Proxy server port.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_synchronizeautomatically: {
      type: 'Optional[Boolean]',
      desc: 'Synchronize automatically.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_setupcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the initial configuration.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_proxyserverbasicauthentication: {
      type: 'Optional[Boolean]',
      desc: 'Allow proxy server basic authentication.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_contentdir: {
      type: 'Optional[String]',
      desc: 'Folder for WSUS update files.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_upstreamserverssl: {
      type: 'Optional[Boolean]',
      desc: 'Use SSL with upstream WSUS server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_upstreamserverport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port of upstream WSUS server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_clienttargetingmode: {
      type: "Optional[Enum['Client', 'client', 'Server', 'server']]",
      desc: 'An enumerated value that describes if how the Target Groups are populated. Client {default}   Server    ',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
